# ListRoles

The response object for a `list_roles` operation.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**limit** | **int** | The maximum number of Roles that could be returned in the response.  | 
**roles** | [**list[RoleV2]**](RoleV2.md) | The roles matching the search criteria | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


